# bioinf_common

[![pypi version](https://img.shields.io/pypi/v/bioinf_common)](https://pypi.org/project/bioinf_common/)
[![license](https://img.shields.io/pypi/l/bioinf_common)](https://pypi.org/project/bioinf_common/)

Aggregation of functionalities needed in multiple projects.


## Installation

First install the following C++ dependencies:
* `armadillo`

Then execute:
```bash
$ ./install.sh
```


## Tests

```bash
$ tox
```
